==> zio-aws-mediapackage_3-5.17.130.1-sources.jar: zio/aws/mediapackage/model/ListTagsForResourceRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.mediapackage.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.ListTagsForResourceRequest =
      zio.aws.mediapackage.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
  ) extends zio.aws.mediapackage.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
  ): zio.aws.mediapackage.model.ListTagsForResourceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackage_3-5.17.171.1-sources.jar: zio/aws/mediapackage/model/ListTagsForResourceRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.mediapackage.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.ListTagsForResourceRequest =
      zio.aws.mediapackage.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
  ) extends zio.aws.mediapackage.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.ListTagsForResourceRequest
  ): zio.aws.mediapackage.model.ListTagsForResourceRequest.ReadOnly =
    new Wrapper(impl)
}
